doc: Clarify doxygen in GroupManager and GroupManagerDB

Change-Id: I35404474de4943cd8c45fecf78cb9a1d335f4e06
Refs: #3287, #3288, #3297
diff --git a/src/group-manager.hpp b/src/group-manager.hpp
index f8adeee..f2d439d 100644
--- a/src/group-manager.hpp
+++ b/src/group-manager.hpp
@@ -49,11 +49,11 @@
    *
    * The namespace of group manager is /<prefix>/read/<dataType>/
    * The group management information (including user cert, schedule) is stored in a database
    * at @p dbDir.
    * The group key will be an RSA key with @p paramLength bytes.
    * The FreshnessPeriod of data packet carrying the keys will be set to @p freshPeriod.
    */
-  GroupManager(const Name& prefix, const Name& dataType, const std::string& dbDir,
+  GroupManager(const Name& prefix, const Name& dataType, const std::string& dbPath,
                const int paramLength, const int freshPeriod);
 
   /**
@@ -49,11 +49,11 @@
    * The namespace of group manager is /<prefix>/read/<dataType>/
    * The group management information (including user cert, schedule) is stored in a database
-   * at @p dbDir.
-   * The group key will be an RSA key with @p paramLength bytes.
-   * The FreshnessPeriod of data packet carrying the keys will be set to @p freshPeriod.
+   * at @p dbPath.
+   * The group key will be an RSA key with @p paramLength bits.
+   * The FreshnessPeriod of data packet carrying the keys will be set to @p freshPeriod hours.
    */